"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: List of input files
inp_files = [
"testin_fast.in",
"testin_v1.in",
"testin_v5.in",
"testin_bigdft.in",
"testin_etsf_io.in",
"testin_libxc.in",
"testin_wannier90.in",
]
